{#
/**
 * Copyright (C) 2020 Xibo Signage Ltd
 *
 * Xibo - Digital Signage - http://www.xibo.org.uk
 *
 * This file is part of Xibo.
 *
 * Xibo is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * Xibo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Xibo.  If not, see <http://www.gnu.org/licenses/>.
 */
#}

{% extends "authed.twig" %}
{% import "inline.twig" as inline %}

{% block actionMenu %}
    <div class="widget-action-menu pull-right">
        <button class="btn btn-info XiboRedirectButton" href="{{ url_for("savedreport.view") }}"><i class="fa fa-eye" aria-hidden="true"></i> {% trans "Saved Reports" %}</button>
    </div>
{% endblock %}

{% block pageContent %}

    <div class="widget">
        <div class="widget-title">
            <i class="fa fa-list"></i>
            {{ metadata.title }}
            <span class="small">({% trans "Generated on: " %}{{ metadata.generatedOn }})</span>
            <div><span class="small">{% trans "From" %} {{ metadata.periodStart }} {% trans "To" %} {{ metadata.periodEnd }}</span></div>
            <div class="clearfix"></div>
        </div>

        <div class="widget-body">
            <div class="XiboGrid" id="{{ random() }}">

                <div class="XiboData card pt-3">
                    <table id="displayAlertsReportPreview" class="table table-striped">
                        <thead>
                        <tr>
                            <th>{% trans "Display ID" %}</th>
                            <th>{% trans "Display" %}</th>
                            <th>{% trans "Event Type" %}</th>
                            <th>{% trans "Start" %}</th>
                            <th>{% trans "End" %}</th>
                            <th>{% trans "Reference" %}</th>
                            <th>{% trans "Detail" %}</th>
                        </tr>
                        </thead>
                        <tbody>

                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

{% endblock %}

{% block javaScript %}
    <script type="text/javascript" nonce="{{ cspNonce }}">

      $(document).ready(function() {

        var outputData = {{ table|json_encode|raw }};

        var table = $("#displayAlertsReportPreview").DataTable({
          language: dataTablesLanguage,
          dom: dataTablesTemplate,
          paging:   false,
          ordering: false,
          info:     false,
          order: [[3, 'desc']],
          searching: false,
          data: outputData,
          columns: [
            {data: 'displayId'},
            {data: 'display'},
            {data: 'eventType', "sortable": false},
            {
              name: 'start',
              data: function(data) {
                if(data.start) {
                  return moment(data.start, 'X').format(jsDateFormat)
                } else {
                  return '';
                }
              }
            },
            {
              name: 'end',
              data: function(data) {
                if(data.end) {
                  return moment(data.end, 'X').format(jsDateFormat)
                } else {
                  return '';
                }
              }
            },
            {data: 'refId'},
            {data: 'detail'}
          ]
        });

        table.on('draw', dataTableDraw);
        table.on('processing.dt', function(e, settings, processing) {
          dataTableProcessing(e, settings, processing);
        });
      });
    </script>
{% endblock %}